@@ -6,6 +6,7 @@ import sys
 import time
 
 import six
+import pytest
 
 import cherrypy
 from cherrypy._cpcompat import (
@@ -254,7 +255,7 @@ class ConnectionCloseTests(helper.CPWebCase):
         self.assertStatus('200 OK')
         self.assertBody(pov)
         # Apache, for example, may emit a Connection header even for HTTP/1.0
-# self.assertNoHeader("Connection")
+        # self.assertNoHeader("Connection")
 
         # Test a keep-alive HTTP/1.0 request.
         self.persistent = True
@@ -269,7 +270,7 @@ class ConnectionCloseTests(helper.CPWebCase):
         self.assertStatus('200 OK')
         self.assertBody(pov)
         # Apache, for example, may emit a Connection header even for HTTP/1.0
-# self.assertNoHeader("Connection")
+        # self.assertNoHeader("Connection")
 
 
 class PipelineTests(helper.CPWebCase):
@@ -663,7 +664,7 @@ class ConnectionTests(helper.CPWebCase):
         conn.putheader('Transfer-Encoding', 'chunked')
         conn.putheader('Content-Type', 'text/plain')
         # Chunked requests don't need a content-length
-##        conn.putheader("Content-Length", len(body))
+        # #        conn.putheader("Content-Length", len(body))
         conn.endheaders()
         conn.send(body)
         response = conn.getresponse()
@@ -759,6 +760,7 @@ def setup_upload_server():
         'server.accepted_queue_timeout': 0.1,
     })
 
+
 reset_names = 'ECONNRESET', 'WSAECONNRESET'
 socket_reset_errors = [
     getattr(errno, name)
@@ -777,6 +779,7 @@ socket_reset_errors += [
 class LimitedRequestQueueTests(helper.CPWebCase):
     setup_server = staticmethod(setup_upload_server)
 
+    @pytest.mark.xfail(reason='#1535')
     def test_queue_full(self):
         conns = []
         overflow_conn = None
@@ -812,7 +815,7 @@ class LimitedRequestQueueTests(helper.CPWebCase):
                 response.begin()
             except socket.error as exc:
                 if exc.args[0] in socket_reset_errors:
-                    pass # Expected.
+                    pass  # Expected.
                 else:
                     tmpl = (
                         'Overflow conn did not get RST. '
@@ -837,6 +840,7 @@ class LimitedRequestQueueTests(helper.CPWebCase):
             if overflow_conn:
                 overflow_conn.close()
 
+
 class BadRequestTests(helper.CPWebCase):
     setup_server = staticmethod(setup_server)
 
