@@ -30,8 +30,7 @@ import unittest
 
 import six
 
-from cherrypy._cpcompat import text_or_bytes, HTTPConnection
-from cherrypy._cpcompat import HTTPSConnection
+from cherrypy._cpcompat import text_or_bytes, HTTPConnection, HTTPSConnection
 
 
 def interface(host):
@@ -106,7 +105,7 @@ class ReloadingTestLoader(unittest.TestLoader):
                 while parts_copy:
                     target = '.'.join(parts_copy)
                     if target in sys.modules:
-                        module = reload(sys.modules[target])
+                        module = six.moves.reload_module(sys.modules[target])
                         parts = unused_parts
                         break
                     else:
@@ -126,9 +125,12 @@ class ReloadingTestLoader(unittest.TestLoader):
 
         if isinstance(obj, types.ModuleType):
             return self.loadTestsFromModule(obj)
-        elif (((six.PY3 and isinstance(obj, type))
-               or isinstance(obj, (type, types.ClassType)))
-              and issubclass(obj, unittest.TestCase)):
+        elif (
+                (
+                    (six.PY3 and isinstance(obj, type)) or
+                    isinstance(obj, (type, types.ClassType))
+                ) and
+                issubclass(obj, unittest.TestCase)):
             return self.loadTestsFromTestCase(obj)
         elif isinstance(obj, types.UnboundMethodType):
             if six.PY3:
@@ -462,7 +464,7 @@ class WebCase(unittest.TestCase):
             self._handlewebError(msg)
 
 
-methods_with_bodies = ('POST', 'PUT')
+methods_with_bodies = ('POST', 'PUT', 'PATCH')
 
 
 def cleanHeaders(headers, method, body, host, port):
@@ -578,8 +580,6 @@ def openURL(url, headers=None, method='GET', body=None,
                     raise
 
 
-
-
 # Add any exceptions which your web framework handles
 # normally (that you don't want server_error to trap).
 ignored_exceptions = []
